@@ -1838,7 +1838,7 @@ def network02(df, entity1, entity2, relation):
     # }
 
 
-    got_net = Network(height="500px", width="500px", bgcolor="white", font_color="black", notebook=True, directed=True)
+    got_net = Network(height="500px", width="500px", bgcolor="white", font_color="black", notebook=False, directed=True)
     # got_net = Network(notebook=True, directed=True)
 
     sources = df[entity1]
@@ -1865,7 +1865,7 @@ def network02(df, entity1, entity2, relation):
         node["title"] += " Neighbors:<br>" + "<br>".join(neighbor_map[node["id"]])
     #    node["value"] = len(neighbor_map[node["id"]])
 
-    return got_net.show("KG_networks.html")
+    return got_net.show("KG_Networks.html")
 
 
 
